@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from dataclasses import dataclass
-from typing import Mapping
+from typing import Any, Callable, Awaitable
 
 from patchwork.core import Component
 
@@ -11,10 +11,15 @@ class Record:
     payload: bytes
 
 
+async def all_allowed(auth, topic):
+    return True
+
+
 class CourtClient:
 
-    def __init__(self, data: Mapping = None):
-        self.data = dict(data if data is not None else {})
+    def __init__(self, auth: Any = None, permissions: Callable[[Any, str], Awaitable[bool]] = None):
+        self.auth = auth
+        self.permissions = permissions or all_allowed
 
     async def __aenter__(self):
         return self
@@ -28,7 +33,9 @@ class CourtClient:
         :param topic:
         :return:
         """
-        raise NotImplementedError()
+        for t in topic:
+            if not await self.permissions(self.auth, t):
+                raise PermissionError(t)
 
     async def unsubscribe(self, *topic: str):
         """
@@ -52,6 +59,6 @@ class Court(Component):
     async def publish(self, record: Record):
         raise NotImplementedError()
 
-    async def client(self, data: Mapping = None) -> CourtClient:
+    async def client(self, auth: Any = None, permissions: Callable[[Any, str], Awaitable[bool]] = None) -> CourtClient:
         raise NotImplementedError()
 
