@@ -17,19 +17,19 @@ class GetCourt(Dependency):
         return ctx.worker.modules[self._name]
 
 
-async def ws_protocol_handler(data: bytes, client: CourtClient) -> bytes:
+async def ws_protocol_handler(data: str, client: CourtClient) -> str:
     """
     Websocket subscriptions protocol handler
     :param data:
     :param client:
     :return:
     """
-    cmd, payload = data.split(b' ', maxsplit=1)
-    if cmd == b'SUBSCRIBE':
+    cmd, payload = data.split(' ', maxsplit=1)
+    if cmd == 'SUBSCRIBE':
         # subscribe, eg. SUBSCRIBE channel-*,private-1
-        await client.subscribe(*tuple(arg.strip().decode() for arg in payload.split(b',')))
-    elif cmd == b'UNSUBSCRIBE':
+        await client.subscribe(*tuple(arg.strip() for arg in payload.split(',')))
+    elif cmd == 'UNSUBSCRIBE':
         # unsubscribe, eg UNSUBSCRIBE channel-1; UNSUBSCRIBE *  (all)
-        await client.unsubscribe(*tuple(arg.strip().decode() for arg in payload.split(b',')))
+        await client.unsubscribe(*tuple(arg.strip() for arg in payload.split(',')))
 
-    return b'OK'
+    return 'OK'
